@@ -3,30 +3,26 @@ use super::geometry::{Ray, Sphere};
 use super::morton::Morton;
 use std::boxed::Box;
 
-#[derive(Clone)]
+/// A node in the BVH.
+#[derive(Clone, Debug, Default)]
 pub struct BvhNode {
+    /// Whether this node is a leaf.
+    /// If it is, then the `left` and `right` fields are None and `primative` isn't.
     pub is_terminal: bool,
+    /// The bounding box of this node.
     pub box_: Aabb,
+    /// One-half of the bounding box. None if `is_terminal` is true.
     pub right: Option<Box<BvhNode>>,
+    /// One-half of the bounding box. None if `is_terminal` is true.
     pub left: Option<Box<BvhNode>>,
+    /// The primitive that this node represents. None if `is_terminal` is false.
     pub primitive: Option<Tri>,
+    /// The morton code of this node.
     pub morton: Option<u64>,
 }
 
-impl Default for BvhNode {
-    fn default() -> Self {
-        Self {
-            is_terminal: false,
-            box_: Aabb::default(),
-            right: None,
-            left: None,
-            primitive: None,
-            morton: None,
-        }
-    }
-}
-
 impl BvhNode {
+    /// Creates a new branch for the BVH given two children.
     pub fn branch(right: Box<BvhNode>, left: Box<BvhNode>) -> Box<Self> {
         Box::new(Self {
             is_terminal: false,
@@ -38,6 +34,7 @@ impl BvhNode {
         })
     }
 
+    /// Creates a new leaf for the BVH given a primitive, its bounding box, and its morton code.
     pub fn leaf(primitive: Tri, box_: Aabb, morton_code: u64) -> Box<Self> {
         Box::new(Self {
             is_terminal: true,
@@ -50,11 +47,14 @@ impl BvhNode {
     }
 }
 
-// BVH stands for "Bounding Volume Hierarchy"
-#[derive(Clone)]
+/// A bounding volume hierarchy.
+#[derive(Clone, Debug, Default)]
 pub struct Bvh {
+    /// The bounding box of the entire BVH.
     pub global_box: Aabb,
+    /// The number of leaves that the BVH has.
     pub num_leaves: u64,
+    /// The root of the BVH.
     pub root: Box<BvhNode>,
 }
 
@@ -68,17 +68,8 @@ fn global_aabb(boxes: &[Aabb]) -> Aabb {
     global_box
 }
 
-impl Default for Bvh {
-    fn default() -> Self {
-        Self {
-            global_box: Aabb::default(),
-            num_leaves: 0,
-            root: Box::new(BvhNode::default()),
-        }
-    }
-}
-
 impl Bvh {
+    /// Creates a new BVH from a list of primitives.
     pub fn from(primitives: &[Tri]) -> Self {
         let num_leaves = primitives.len();
 
@@ -125,13 +116,13 @@ impl Bvh {
         BvhNode::branch(right, left)
     }
 
+    /// Returns a Vec of the triangles intersecting with the `query_object`.
     pub fn intersect(&self, query_object: &Sphere) -> Vec<Tri> {
         let query_box: Aabb = query_object.into();
 
         let mut hits = Vec::with_capacity(16);
 
-        // Allocate traversal stack from thread-local memory,
-        // and push NULL to indicate that there are no postponed nodes.
+        // Allocate traversal stack from thread-local memory
         let mut stack: Vec<&BvhNode> = Vec::with_capacity(32);
 
         // Traverse nodes starting from the root.
@@ -193,6 +184,8 @@ impl Bvh {
         hits
     }
 
+    /// Returns the calculated ray-intersection of the given Sphere and the BVH.
+    /// Returns None if no intersecting objects were found in the BVH.
     pub fn collide(&self, s: &Sphere) -> Option<Ray> {
         let mut contact_point = Ray::default();
         let mut count = 0;
@@ -238,85 +231,42 @@ mod test {
 
     #[test]
     fn global_bounding_box() {
-        let bounding_boxes = vec![
-            Aabb {
-                min: vec3a(MIN_X, 0.0, 0.0),
-                max: Vec3A::ZERO,
-            },
-            Aabb {
-                min: vec3a(0.0, MIN_Y, 0.0),
-                max: Vec3A::ZERO,
-            },
-            Aabb {
-                min: vec3a(0.0, 0.0, MIN_Z),
-                max: Vec3A::ZERO,
-            },
-            Aabb {
-                min: Vec3A::ZERO,
-                max: vec3a(MAX_X, 0.0, 0.0),
-            },
-            Aabb {
-                min: Vec3A::ZERO,
-                max: vec3a(0.0, MAX_Y, 0.0),
-            },
-            Aabb {
-                min: Vec3A::ZERO,
-                max: vec3a(0.0, 0.0, MAX_Z),
-            },
-        ];
+        let bounding_boxes = vec![Aabb::from(vec3a(MIN_X, 0.0, 0.0), Vec3A::ZERO), Aabb::from(vec3a(0.0, MIN_Y, 0.0), Vec3A::ZERO), Aabb::from(vec3a(0.0, 0.0, MIN_Z), Vec3A::ZERO), Aabb::from(Vec3A::ZERO, vec3a(MAX_X, 0.0, 0.0)), Aabb::from(Vec3A::ZERO, vec3a(0.0, MAX_Y, 0.0)), Aabb::from(Vec3A::ZERO, vec3a(0.0, 0.0, MAX_Z))];
 
         let global = global_aabb(&bounding_boxes);
 
-        assert!((global.min.x - MIN_X).abs() < f32::EPSILON);
-        assert!((global.min.y - MIN_Y).abs() < f32::EPSILON);
-        assert!((global.min.z - MIN_Z).abs() < f32::EPSILON);
-        assert!((global.max.x - MAX_X).abs() < f32::EPSILON);
-        assert!((global.max.y - MAX_Y).abs() < f32::EPSILON);
-        assert!((global.max.z - MAX_Z).abs() < f32::EPSILON);
+        assert!((global.min().x - MIN_X).abs() < f32::EPSILON);
+        assert!((global.min().y - MIN_Y).abs() < f32::EPSILON);
+        assert!((global.min().z - MIN_Z).abs() < f32::EPSILON);
+        assert!((global.max().x - MAX_X).abs() < f32::EPSILON);
+        assert!((global.max().y - MAX_Y).abs() < f32::EPSILON);
+        assert!((global.max().z - MAX_Z).abs() < f32::EPSILON);
     }
 
     #[test]
     fn global_bounding_box_min() {
-        let bounding_boxes = vec![
-            Aabb {
-                min: vec3a(MIN_X, MIN_Y, MIN_Z),
-                max: vec3a(MIN_X, MIN_Y, MIN_Z),
-            },
-            Aabb {
-                min: vec3a(MIN_X, MIN_Y, MIN_Z),
-                max: vec3a(MIN_X, MIN_Y, MIN_Z),
-            },
-        ];
+        let bounding_boxes = vec![Aabb::from(vec3a(MIN_X, MIN_Y, MIN_Z), vec3a(MIN_X, MIN_Y, MIN_Z)), Aabb::from(vec3a(MIN_X, MIN_Y, MIN_Z), vec3a(MIN_X, MIN_Y, MIN_Z))];
         let global = global_aabb(&bounding_boxes);
 
-        assert!((global.min.x - MIN_X).abs() < f32::EPSILON);
-        assert!((global.min.y - MIN_Y).abs() < f32::EPSILON);
-        assert!((global.min.z - MIN_Z).abs() < f32::EPSILON);
-        assert!((global.max.x - MIN_X).abs() < f32::EPSILON);
-        assert!((global.max.y - MIN_Y).abs() < f32::EPSILON);
-        assert!((global.max.z - MIN_Z).abs() < f32::EPSILON);
+        assert!((global.min().x - MIN_X).abs() < f32::EPSILON);
+        assert!((global.min().y - MIN_Y).abs() < f32::EPSILON);
+        assert!((global.min().z - MIN_Z).abs() < f32::EPSILON);
+        assert!((global.max().x - MIN_X).abs() < f32::EPSILON);
+        assert!((global.max().y - MIN_Y).abs() < f32::EPSILON);
+        assert!((global.max().z - MIN_Z).abs() < f32::EPSILON);
     }
 
     #[test]
     fn global_bounding_box_max() {
-        let bounding_boxes = vec![
-            Aabb {
-                min: vec3a(MAX_X, MAX_Y, MAX_Z),
-                max: vec3a(MAX_X, MAX_Y, MAX_Z),
-            },
-            Aabb {
-                min: vec3a(MAX_X, MAX_Y, MAX_Z),
-                max: vec3a(MAX_X, MAX_Y, MAX_Z),
-            },
-        ];
+        let bounding_boxes = vec![Aabb::from(vec3a(MAX_X, MAX_Y, MAX_Z), vec3a(MAX_X, MAX_Y, MAX_Z)), Aabb::from(vec3a(MAX_X, MAX_Y, MAX_Z), vec3a(MAX_X, MAX_Y, MAX_Z))];
         let global = global_aabb(&bounding_boxes);
 
-        assert!((global.min.x - MAX_X).abs() < f32::EPSILON);
-        assert!((global.min.y - MAX_Y).abs() < f32::EPSILON);
-        assert!((global.min.z - MAX_Z).abs() < f32::EPSILON);
-        assert!((global.max.x - MAX_X).abs() < f32::EPSILON);
-        assert!((global.max.y - MAX_Y).abs() < f32::EPSILON);
-        assert!((global.max.z - MAX_Z).abs() < f32::EPSILON);
+        assert!((global.min().x - MAX_X).abs() < f32::EPSILON);
+        assert!((global.min().y - MAX_Y).abs() < f32::EPSILON);
+        assert!((global.min().z - MAX_Z).abs() < f32::EPSILON);
+        assert!((global.max().x - MAX_X).abs() < f32::EPSILON);
+        assert!((global.max().y - MAX_Y).abs() < f32::EPSILON);
+        assert!((global.max().z - MAX_Z).abs() < f32::EPSILON);
     }
 
     static VERT_MAP: &[[usize; 3]; 12] = &[[1, 0, 2], [3, 1, 2], [7, 5, 6], [4, 6, 5], [2, 0, 4], [6, 2, 4], [7, 3, 5], [1, 5, 3], [4, 0, 1], [5, 4, 1], [7, 6, 3], [2, 3, 6]];
